
bind PotMeter <Any-Enter> {
	focus -force %W
}

frame .base -relief raised -bd 3

proc addGraphic { frame name index } {
	frame $frame.${name}${index}

	set command "setGraphic $name $index"

	scale $frame.${name}$index.s -length 100 -showvalue false -width 10 \
		-command $command -from 256 -to 0 -variable ${name}$index
	$frame.${name}$index.s set 128
	label $frame.${name}$index.l -text ${name}$index

	pack $frame.${name}$index.s $frame.${name}$index.l -side top
	pack $frame.${name}$index -side left -padx 2
}

proc addGraphics { frame name } {
	frame $frame -relief ridge -bd 3

	for {set index 0} \
		{$index != 8} \
		{set index [expr $index + 1]} {
		addGraphic $frame $name $index
	}

	pack $frame -side left -padx 10 -pady 5 -anchor n
}

proc addVuMeter { frame } {
	frame $frame -relief ridge -bd 3
	label $frame.top -text "Spectral Analysis" -font 6x9

	frame $frame.vu -relief ridge -bd 3 -bg black
	vumeter $frame.vu.vu -variable vuVar -height 64 -width 128 \
		-holdcount 2 -decay1 1 -decay2 1

	frame $frame.mon
	radiobutton $frame.mon.lpre -indicatoron false -text "Pre" -variable lmon \
		-command "setGraphic monitorL pre" -selectcolor green -value pre
	radiobutton $frame.mon.lpost -indicatoron false -text "Post" -variable lmon\
		-command "setGraphic monitorL post" -selectcolor green -value post
	radiobutton $frame.mon.rpre -indicatoron false -text "Pre" -variable rmon \
		-command "setGraphic monitorR pre" -selectcolor green -value pre
	radiobutton $frame.mon.rpost -indicatoron false -text "Post" -variable rmon\
		-command "setGraphic monitorR post" -selectcolor green -value post
	pack $frame.mon.lpre -side left
	pack $frame.mon.lpost -side left
	pack $frame.mon.rpre -side left
	pack $frame.mon.rpost -side left

	frame $frame.text
	label $frame.text.left -text Left -relief ridge -bd 3 -font 6x9
	label $frame.text.right -text Right -relief ridge -bd 3 -font 6x9

	pack $frame.top -side top -expand n -fill x
	pack $frame.vu -expand y -fill y
	pack $frame.vu.vu -side left -anchor w
	pack $frame.mon -side top

	pack $frame.text -side bottom -expand n -fill x -anchor s
	pack $frame.text.left -side left -expand y -fill x
	pack $frame.text.right -side left -expand y -fill x
	pack $frame -side left -pady 5 -anchor n -expand y -fill y

	bind $frame.vu.vu <Button-3> {
		if [catch {tk_popup %W.menu %X %Y} results] {
		}
	}
}

proc addControl { frame name } {
	frame $frame -relief ridge -bd 3

	frame $frame.l

	set command "setGraphic left vol"
	scale $frame.l.s -length 100 -showvalue false -width 10 \
		-command $command -from 256 -to 0 -variable left
	$frame.l.s set 256
	label $frame.l.l -text lft
	pack $frame.l.s $frame.l.l -side top
	pack $frame.l -side left

	frame $frame.c
	set command "setGraphic main vol"
	scale $frame.c.s -length 100 -showvalue false -width 10 \
		-command $command -from 512 -to 0 -variable main
	$frame.c.s set 256
	label $frame.c.l -text volume
	pack $frame.c.s $frame.c.l -side top
	pack $frame.c -side left

	frame $frame.r
	set command "setGraphic right vol"
	scale $frame.r.s -length 100 -showvalue false -width 10 \
		-command $command -from 256 -to 0 -variable right
	$frame.r.s set 256
	label $frame.r.l -text rgt

	pack $frame.r.s $frame.r.l -side top
	pack $frame.r -side left

	pack $frame -side left -padx 5 -padx 10 -pady 5 -anchor n
}

proc setGraphicMem { file } {
	global bvMem

	setGraphic memset $file $bvMem
}

#
# Put memories into buttons:
#
proc buildMemories { frame } {
	global memoryFileName bvMem

	#
	# Want to get some values from a config file, if possible.
	#
	set memoryFileName [setGraphic getfilename].graphic

	frame $frame -relief ridge -bd 3

	radiobutton $frame.m0 -indicatoron false -text M0 -variable bvMem -value 0 \
		-command "setGraphic memget $memoryFileName 0" \
		-highlightthickness 0 -selectcolor lightblue
	radiobutton $frame.m1 -indicatoron false -text M1 -variable bvMem -value 1 \
		-command "setGraphic memget $memoryFileName 1" \
		-highlightthickness 0 -selectcolor lightblue
	radiobutton $frame.m2 -indicatoron false -text M2 -variable bvMem -value 2 \
		-command "setGraphic memget $memoryFileName 2" \
		-highlightthickness 0 -selectcolor lightblue
	radiobutton $frame.m3 -indicatoron false -text M3 -variable bvMem -value 3 \
		-command "setGraphic memget $memoryFileName 3" \
		-highlightthickness 0 -selectcolor lightblue
	button $frame.save -text Set -command "setGraphicMem $memoryFileName" \
		-highlightthickness 0 -bd 1 -fg red -pady 0 -padx 0

	pack $frame.m0 $frame.m1 $frame.m2 $frame.m3 -side top \
		-expand y -fill both
	pack $frame.save -side bottom -padx 0 -pady 0 -expand n -fill both

	pack $frame -side left -expand y -fill y -padx 3 -pady 5 -ipadx 3 -ipady 3

	#
	# Load the first file is possible
	#
	catch {setGraphic memget $memoryFileName 0}
	set bvMem 0
}

proc buildMemyMenu {} {
	global memoryFileName

	#
	# Want to get some values from a config file, if possible.
	#
	set memoryFileName [setGraphic getfilename].stGraphic
puts $memoryFileName
	menu .base.mem
	.base.mem add cascade -menu .base.mem.load -label "Load"
	.base.mem add cascade -menu .base.mem.save -label "Save"
	menu .base.mem.load
	.base.mem.load add command -label "Memory 0" -command \
		"setGraphic memget $memoryFileName 0"
	.base.mem.load add command -label "Memory 1" -command \
		"setGraphic memget $memoryFileName 1"
	.base.mem.load add command -label "Memory 2" -command \
		"setGraphic memget $memoryFileName 2"
	.base.mem.load add command -label "Memory 3" -command \
		"setGraphic memget $memoryFileName 3"
	menu .base.mem.save
	.base.mem.save add command -label "Memory 0" -command \
		"setGraphic memset $memoryFileName 0"
	.base.mem.save add command -label "Memory 1" -command \
		"setGraphic memset $memoryFileName 1"
	.base.mem.save add command -label "Memory 2" -command \
		"setGraphic memset $memoryFileName 2"
	.base.mem.save add command -label "Memory 3" -command \
		"setGraphic memset $memoryFileName 3"

	bind SLab <Button-3> {
		catch {tk_popup .base.mem %X %Y}
	}

	#
	# Load the first file is possible
	#
	catch {setGraphic memget $memoryFileName 0}
}

proc buildPanel { frame } {
	addGraphics $frame.left l
	addVuMeter $frame.vu
	addGraphics $frame.right r
	addControl $frame.c c
	buildMemories $frame.mem
}

set lmon pre
set rmon pre

buildPanel .base
pack .base
bindtags .base {SLab 2 3 4}

wm title . "Stereo Graphic Spectral Analyser"

after 300 checkDataPath

